# -*- coding: UTF-8 -*-
# generated by lino.sphinxcontrib.help_text_builder
from __future__ import unicode_literals
from django.utils.translation import gettext_lazy as _

help_texts = {
    'lino_amici.lib.amici.migrate.Migrator':
    _("""The standard migrator for noi."""),
    'lino_amici.lib.amici.user_types.EndUser':
    _("""An end user is somebody who uses our database, but won't work
on it."""),
    'lino_amici.lib.amici.user_types.Collector':
    _("""A collector is somebody who collects data into the database."""),
    'lino_amici.lib.amici.user_types.ProjectManager':
    _("""A project manager additionally sees tickets, projects, courses,
meetings, calendar..."""),
    'lino_amici.lib.amici.user_types.SiteAdmin':
    _("""Can do everything."""),
}
